Python package for Premod solver
================================

This folder contains the premod python package.
It's helping to work with the Premod solver: pre- and post-processing.


Install
-------

```
cd premod/python
pip install --editable . --user
pytest
```

